# This file is the entry point to configure your own services.
# Files in the packages/ subdirectory configure your dependencies.

# Put parameters here that don't need to change on each machine where the app is deployed
# https://symfony.com/doc/current/best_practices/configuration.html#application-related-configuration
parameters:
    OPENAI_API_KEY: '%env(OPENAI_API_KEY)%'
    APP_ENV: '%env(APP_ENV)%'
    locale: 'fr'
    # This parameter defines the codes of the locales (languages) enabled in the application
    locales: fr|de|es|cn|en
    app_locales: fr|de|es|cn|en
    flag_directory: '%kernel.project_dir%/public/uploads/flags'
    images_directory:  '%kernel.project_dir%/public/uploads/images'
    modele_gallery_directory:  '%kernel.project_dir%/public/uploads/model-gallery'
    gallery_directory:  '%kernel.project_dir%/public/uploads/gallery'
    media_directory:  '%kernel.project_dir%/public/uploads/media'
    doc_directory:  '%kernel.project_dir%/public/uploads/documents'
    imports_directory:  '%kernel.project_dir%/public/uploads/hrz/import_csv'
    icon_directory:  '%kernel.project_dir%/public/uploads/type_affichage/icons'
    crop_img_directory:  '%kernel.project_dir%/public/thumbs'
    indexation_search_directory:  '%kernel.project_dir%/indexation'
    traductions_export:  '%kernel.project_dir%/public/traductions/export'
    traductions_import:  '%kernel.project_dir%/public/traductions/import'
    data_import:  '%kernel.project_dir%/public/data_import'
    oplead_logs:  '%kernel.project_dir%/public'
    app.public_dir: '%kernel.project_dir%/public/images'
    app.image_cache_dir: '%kernel.project_dir%/var/storage/cache'
    app.thumbnails: '%kernel.project_dir%/public/thumbnails'

services:
    #doctrine_behaviors_translatable_fetch_mode: "LAZY"
    #doctrine_behaviors_translation_fetch_mode: "LAZY"
    # default configuration for services in *this* file
    _defaults:
        autowire: true      # Automatically injects dependencies in your services.
        autoconfigure: true # Automatically registers your services as commands, event subscribers, etc.
        bind:               # defines the scalar arguments once and apply them to any service defined/created in this file
           $locales: '%locales%'
           $defaultLocale: '%locale%'
           $locale: '%locale%'
           $importMediaDirectory: '%kernel.project_dir%/public/import_media'
           $mediaDirectory:  '%kernel.project_dir%/public/uploads/media'
           $projectPublic: '%kernel.project_dir%/public'
           $projectDir: '%kernel.project_dir%/public/files'
           $storageCacheDir: '%kernel.project_dir%/public/storage'
           $thumbs: '%kernel.project_dir%/public/thumbs'
           $projectCache: '%kernel.project_dir%/var/storage/cache/thumbnails'
           $projectDirEditor: '%kernel.project_dir%/public/uploads/files'
           $projectDirr: '%kernel.project_dir%'
           $theme: '%env(APP_THEME)%'
           $secret: '%kernel.secret%'

    
    # makes classes in src/ available to be used as services
    # this creates a service per class whose id is the fully-qualified class name
    App\:
        resource: '../src/*'
        exclude: '../src/{DependencyInjection,Entity,Migrations,Tests,Kernel.php}'

    # controllers are imported separately to make sure services can be injected
    # as action arguments even if you don't extend any base controller class
    App\Controller\:
        resource: '../src/Controller'
        tags: ['controller.service_arguments']

    # add more service definitions when explicit configuration is needed
    # please note that last definitions always *replace* previous ones
    App\EventSubscriber\LocaleSubscriber:
        arguments: ['%kernel.default_locale%']

    App\Service\FileUploader:
        arguments:
            $targetDirectory: '%flag_directory%'


    sensio_framework_extra.view.listener:
        alias: Sensio\Bundle\FrameworkExtraBundle\EventListener\TemplateListener

    App\Twig\TemplateBlocExtension:
        public: false
        arguments: ['@doctrine.orm.entity_manager']
        tags:
            # extensions with higher priorities are registered earlier
            - { name: twig.extension}

    App\Twig\TemplateWidgetExtenstion:
        public: false
        arguments: ['@doctrine.orm.entity_manager']
        tags:
            # extensions with higher priorities are registered earlier
            - { name: twig.extension}

    App\Twig\ParametreSiteExtension:
        public: false
        arguments: ['@doctrine.orm.entity_manager']
        tags:
            # extensions with higher priorities are registered earlier
            - { name: twig.extension}

    App\Service\BuildTree:
        public: false
        arguments: ['@doctrine.orm.entity_manager']


    App\EventListener\SitemapSubscriber:
        public: false
        arguments: 
            - "@router"
        tags:
            - { name: "kernel.event_subscriber", priority: 100 }

    # acme.twig.extension.loader:
    #     class: Twig\Extension\StringLoaderExtension
    #     tags:
    #         - { name: 'twig.extension' }

    App\Twig\OrderExtension:
        tags:
            - { name: twig.extension }
        arguments: ['@router']

    App\Service\Link:
        public: true
        arguments: ['@doctrine.orm.entity_manager', '@router']

    League\Glide\Server:
        factory: ['League\Glide\ServerFactory', create]
        arguments: 
          - { source: '%app.public_dir%', cache: '%app.image_cache_dir%' }

    App\Service\EncryptionService:
        public: true
        arguments:
            $encryptionKey: '%encryption_key%'
    
    App\Service\AffichageGallerieService:
        public: true


    

